@@ -3,7 +3,7 @@ from PyQt5 import QtGui
 
 from linien.common import convert_channel_mixing_value, FAST_OUT1, FAST_OUT2, \
     ANALOG_OUT0
-from linien.client.utils import param2ui
+from linien.client.utils_gui import param2ui
 from linien.client.widgets import CustomWidget
 from linien.client.connection import MHz, Vpp
 
@@ -33,7 +33,6 @@ class GeneralPanel(QtGui.QWidget, CustomWidget):
 
         def dual_channel_changed(value):
             self.ids.dual_channel_mixing.setVisible(value)
-            self.app().main_window.ids.spectroscopy_channel_2_page.setEnabled(value)
             return value
         param2ui(
             params.dual_channel,
