@@ -2,7 +2,7 @@ import numpy as np
 from PyQt5 import QtGui
 from linien.client.widgets import CustomWidget
 from linien.client.connection import MHz, Vpp
-from linien.client.utils import param2ui
+from linien.client.utils_gui import param2ui
 
 
 class ModulationAndRampPanel(QtGui.QWidget, CustomWidget):
@@ -54,5 +54,5 @@ class ModulationAndRampPanel(QtGui.QWidget, CustomWidget):
         self.control.write_data()
 
     def dual_channel_changed(self, value):
-        self.ids.spectroscopyBPanel.setVisible(value)
+        self.ids.spectroscopyBPanel.setEnabled(value)
         self.ids.spectroscopyBPanelDisabled.setVisible(not value)
\ No newline at end of file
