@@ -77,10 +77,10 @@ class ViewPanel(QtGui.QWidget, CustomWidget):
             data['to_plot'] = pickle.loads(data['to_plot'])
 
             # filter out keys that are not json-able
-            for k, v in data.items():
+            for k, v in list(data.items()):
                 try:
                     json.dumps(v)
                 except:
                     del data[k]
 
-            json.dump(data, f)
\ No newline at end of file
+            json.dump(data, f)
